Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.cpp	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.cpp	(revision 84625)
@@ -574,5 +574,5 @@
 }
 
-void UIChooserAbstractModel::performSearch(const QString &strSearchTerm, int iItemSearchFlags)
+void UIChooserAbstractModel::performSearch(const QString &strSearchTerm, int iSearchFlags)
 {
     /* Make sure invisible root exists: */
@@ -591,11 +591,10 @@
 
     /* Search for all the nodes matching required condition: */
-    invisibleRoot()->searchForNodes(strSearchTerm, iItemSearchFlags, m_searchResults);
+    invisibleRoot()->searchForNodes(strSearchTerm, iSearchFlags, m_searchResults);
 
     /* Assign/reset the disabled flag for required nodes: */
     foreach (UIChooserNode *pNode, nodes)
     {
-        if (!pNode)
-            continue;
+        AssertPtrReturnVoid(pNode);
         pNode->setDisabled(!m_searchResults.contains(pNode));
     }
@@ -610,5 +609,5 @@
     AssertPtrReturn(invisibleRoot(), nodes);
 
-    /* Calling UIChooserNode::searchForNodes with an empty search string
+    /* Calling UIChooserNode::searchForNodes with an empty search term
      * returns a list all nodes (of the whole tree) of the required type: */
     invisibleRoot()->searchForNodes(QString(), UIChooserItemSearchFlag_Machine, nodes);
@@ -617,6 +616,5 @@
     foreach (UIChooserNode *pNode, nodes)
     {
-        if (!pNode)
-            continue;
+        AssertPtrReturn(pNode, nodes);
         pNode->setDisabled(false);
     }
@@ -625,5 +623,5 @@
     m_searchResults.clear();
 
-    /* Return  nodes: */
+    /* Return nodes: */
     return nodes;
 }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemGlobal.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemGlobal.cpp	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemGlobal.cpp	(revision 84625)
@@ -210,8 +210,8 @@
 }
 
-UIChooserItem *UIChooserItemGlobal::searchForItem(const QString &, int iItemSearchFlags)
+UIChooserItem *UIChooserItemGlobal::searchForItem(const QString &, int iSearchFlags)
 {
     /* Ignore if we are not searching for the global-item: */
-    if (!(iItemSearchFlags & UIChooserItemSearchFlag_Global))
+    if (!(iSearchFlags & UIChooserItemSearchFlag_Global))
         return 0;
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemGroup.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemGroup.cpp	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemGroup.cpp	(revision 84625)
@@ -494,16 +494,16 @@
 }
 
-UIChooserItem* UIChooserItemGroup::searchForItem(const QString &strSearchTag, int iItemSearchFlags)
+UIChooserItem* UIChooserItemGroup::searchForItem(const QString &strSearchTag, int iSearchFlags)
 {
     /* Are we searching among group-items? */
-    if (   (   iItemSearchFlags & UIChooserItemSearchFlag_LocalGroup
+    if (   (   iSearchFlags & UIChooserItemSearchFlag_LocalGroup
             && groupType() == UIChooserNodeGroupType_Local)
-        || (   iItemSearchFlags & UIChooserItemSearchFlag_CloudProvider
+        || (   iSearchFlags & UIChooserItemSearchFlag_CloudProvider
             && groupType() == UIChooserNodeGroupType_Provider)
-        || (   iItemSearchFlags & UIChooserItemSearchFlag_CloudProfile
+        || (   iSearchFlags & UIChooserItemSearchFlag_CloudProfile
             && groupType() == UIChooserNodeGroupType_Profile))
     {
         /* Are we searching by the exact ID? */
-        if (iItemSearchFlags & UIChooserItemSearchFlag_ExactId)
+        if (iSearchFlags & UIChooserItemSearchFlag_ExactId)
         {
             /* Exact full-name matches? */
@@ -512,5 +512,5 @@
         }
         /* Are we searching by the exact name? */
-        else if (iItemSearchFlags & UIChooserItemSearchFlag_ExactName)
+        else if (iSearchFlags & UIChooserItemSearchFlag_ExactName)
         {
             /* Exact name matches? */
@@ -529,11 +529,11 @@
     /* Search among all the children, but machines first: */
     foreach (UIChooserItem *pItem, items(UIChooserNodeType_Machine))
-        if (UIChooserItem *pFoundItem = pItem->searchForItem(strSearchTag, iItemSearchFlags))
+        if (UIChooserItem *pFoundItem = pItem->searchForItem(strSearchTag, iSearchFlags))
             return pFoundItem;
     foreach (UIChooserItem *pItem, items(UIChooserNodeType_Global))
-        if (UIChooserItem *pFoundItem = pItem->searchForItem(strSearchTag, iItemSearchFlags))
+        if (UIChooserItem *pFoundItem = pItem->searchForItem(strSearchTag, iSearchFlags))
             return pFoundItem;
     foreach (UIChooserItem *pItem, items(UIChooserNodeType_Group))
-        if (UIChooserItem *pFoundItem = pItem->searchForItem(strSearchTag, iItemSearchFlags))
+        if (UIChooserItem *pFoundItem = pItem->searchForItem(strSearchTag, iSearchFlags))
             return pFoundItem;
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemMachine.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemMachine.cpp	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemMachine.cpp	(revision 84625)
@@ -265,12 +265,12 @@
 }
 
-UIChooserItem* UIChooserItemMachine::searchForItem(const QString &strSearchTag, int iItemSearchFlags)
+UIChooserItem* UIChooserItemMachine::searchForItem(const QString &strSearchTag, int iSearchFlags)
 {
     /* Ignore if we are not searching for the machine-item: */
-    if (!(iItemSearchFlags & UIChooserItemSearchFlag_Machine))
+    if (!(iSearchFlags & UIChooserItemSearchFlag_Machine))
         return 0;
 
     /* Are we searching by the exact ID? */
-    if (iItemSearchFlags & UIChooserItemSearchFlag_ExactId)
+    if (iSearchFlags & UIChooserItemSearchFlag_ExactId)
     {
         /* Exact ID doesn't match? */
@@ -279,5 +279,5 @@
     }
     /* Are we searching by the exact name? */
-    else if (iItemSearchFlags & UIChooserItemSearchFlag_ExactName)
+    else if (iSearchFlags & UIChooserItemSearchFlag_ExactName)
     {
         /* Exact name doesn't match? */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.cpp	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.cpp	(revision 84625)
@@ -512,8 +512,8 @@
 }
 
-void UIChooserModel::performSearch(const QString &strSearchTerm, int iItemSearchFlags)
+void UIChooserModel::performSearch(const QString &strSearchTerm, int iSearchFlags)
 {
     /* Call to base-class: */
-    UIChooserAbstractModel::performSearch(strSearchTerm, iItemSearchFlags);
+    UIChooserAbstractModel::performSearch(strSearchTerm, iSearchFlags);
 
     /* Select 1st found item: */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeGlobal.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeGlobal.cpp	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeGlobal.cpp	(revision 84625)
@@ -130,8 +130,8 @@
 }
 
-void UIChooserNodeGlobal::searchForNodes(const QString &strSearchTerm, int iItemSearchFlags, QList<UIChooserNode*> &matchedItems)
+void UIChooserNodeGlobal::searchForNodes(const QString &strSearchTerm, int iSearchFlags, QList<UIChooserNode*> &matchedItems)
 {
     /* Ignore if we are not searching for the global-node: */
-    if (!(iItemSearchFlags & UIChooserItemSearchFlag_Global))
+    if (!(iSearchFlags & UIChooserItemSearchFlag_Global))
         return;
 
@@ -142,5 +142,5 @@
     {
         /* If exact name flag specified => check full node name: */
-        if (iItemSearchFlags & UIChooserItemSearchFlag_ExactName)
+        if (iSearchFlags & UIChooserItemSearchFlag_ExactName)
         {
             if (name() == strSearchTerm)
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeGroup.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeGroup.cpp	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeGroup.cpp	(revision 84625)
@@ -224,12 +224,12 @@
 }
 
-void UIChooserNodeGroup::searchForNodes(const QString &strSearchTerm, int iItemSearchFlags, QList<UIChooserNode*> &matchedItems)
+void UIChooserNodeGroup::searchForNodes(const QString &strSearchTerm, int iSearchFlags, QList<UIChooserNode*> &matchedItems)
 {
     /* If we are searching for the group-node: */
-    if (   (   iItemSearchFlags & UIChooserItemSearchFlag_LocalGroup
+    if (   (   iSearchFlags & UIChooserItemSearchFlag_LocalGroup
             && groupType() == UIChooserNodeGroupType_Local)
-        || (   iItemSearchFlags & UIChooserItemSearchFlag_CloudProvider
+        || (   iSearchFlags & UIChooserItemSearchFlag_CloudProvider
             && groupType() == UIChooserNodeGroupType_Provider)
-        || (   iItemSearchFlags & UIChooserItemSearchFlag_CloudProfile
+        || (   iSearchFlags & UIChooserItemSearchFlag_CloudProfile
             && groupType() == UIChooserNodeGroupType_Profile))
     {
@@ -240,5 +240,5 @@
         {
             /* If exact ID flag specified => check full node name: */
-            if (iItemSearchFlags & UIChooserItemSearchFlag_ExactId)
+            if (iSearchFlags & UIChooserItemSearchFlag_ExactId)
             {
                 if (fullName() == strSearchTerm)
@@ -246,5 +246,5 @@
             }
             /* If exact name flag specified => check node name: */
-            else if (iItemSearchFlags & UIChooserItemSearchFlag_ExactName)
+            else if (iSearchFlags & UIChooserItemSearchFlag_ExactName)
             {
                 if (name() == strSearchTerm)
@@ -262,9 +262,9 @@
     /* Search among all the children: */
     foreach (UIChooserNode *pNode, m_nodesGroup)
-        pNode->searchForNodes(strSearchTerm, iItemSearchFlags, matchedItems);
+        pNode->searchForNodes(strSearchTerm, iSearchFlags, matchedItems);
     foreach (UIChooserNode *pNode, m_nodesGlobal)
-        pNode->searchForNodes(strSearchTerm, iItemSearchFlags, matchedItems);
+        pNode->searchForNodes(strSearchTerm, iSearchFlags, matchedItems);
     foreach (UIChooserNode *pNode, m_nodesMachine)
-        pNode->searchForNodes(strSearchTerm, iItemSearchFlags, matchedItems);
+        pNode->searchForNodes(strSearchTerm, iSearchFlags, matchedItems);
 }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeMachine.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeMachine.cpp	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeMachine.cpp	(revision 84625)
@@ -195,8 +195,8 @@
 }
 
-void UIChooserNodeMachine::searchForNodes(const QString &strSearchTerm, int iItemSearchFlags, QList<UIChooserNode*> &matchedItems)
+void UIChooserNodeMachine::searchForNodes(const QString &strSearchTerm, int iSearchFlags, QList<UIChooserNode*> &matchedItems)
 {
     /* Ignore if we are not searching for the machine-node: */
-    if (!(iItemSearchFlags & UIChooserItemSearchFlag_Machine))
+    if (!(iSearchFlags & UIChooserItemSearchFlag_Machine))
         return;
 
@@ -207,5 +207,5 @@
     {
         /* If exact ID flag specified => check node ID:  */
-        if (iItemSearchFlags & UIChooserItemSearchFlag_ExactId)
+        if (iSearchFlags & UIChooserItemSearchFlag_ExactId)
         {
             if (id() == QUuid(strSearchTerm))
@@ -213,5 +213,5 @@
         }
         /* If exact name flag specified => check full node name: */
-        else if (iItemSearchFlags & UIChooserItemSearchFlag_ExactName)
+        else if (iSearchFlags & UIChooserItemSearchFlag_ExactName)
         {
             if (name() == strSearchTerm)
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserSearchWidget.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserSearchWidget.h	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserSearchWidget.h	(revision 84625)
@@ -41,5 +41,5 @@
 signals:
 
-    void sigRedoSearch(const QString &strSearchTerm, int iItemSearchFlags);
+    void sigRedoSearch(const QString &strSearchTerm, int iSearchFlags);
     /** Is being signalled as next/prev tool buttons are pressed. @a fIsNext is true
       * for the next and false for the previous case. */

Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.h	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.h	(revision 84625)
@@ -91,7 +91,7 @@
     /** @name Search stuff.
       * @{ */
-        /** Performs a search starting from the m_pInvisibleRootNode. */
-        virtual void performSearch(const QString &strSearchTerm, int iItemSearchFlags);
-        /** Cleans the search result data members and disables item's visual effects.
+        /** Performs a search using @a strSearchTerm and @a iSearchFlags specified. */
+        virtual void performSearch(const QString &strSearchTerm, int iSearchFlags);
+        /** Resets the search result data members and disables item's visual effects.
           * Also returns a list of all nodes which may be utilized by the calling code. */
         virtual QList<UIChooserNode*> resetSearch();
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItem.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItem.h	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItem.h	(revision 84625)
@@ -168,6 +168,6 @@
         virtual void removeItem(UIChooserItem *pItem) = 0;
 
-        /** Searches for a first child item answering to specified @a strSearchTag and @a iItemSearchFlags. */
-        virtual UIChooserItem *searchForItem(const QString &strSearchTag, int iItemSearchFlags) = 0;
+        /** Searches for a first child item answering to specified @a strSearchTag and @a iSearchFlags. */
+        virtual UIChooserItem *searchForItem(const QString &strSearchTag, int iSearchFlags) = 0;
 
         /** Searches for a first machine child item. */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemGlobal.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemGlobal.h	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemGlobal.h	(revision 84625)
@@ -110,6 +110,6 @@
         virtual void removeItem(UIChooserItem *pItem) /* override */;
 
-        /** Searches for a first child item answering to specified @a strSearchTag and @a iItemSearchFlags. */
-        virtual UIChooserItem *searchForItem(const QString &strSearchTag, int iItemSearchFlags) /* override */;
+        /** Searches for a first child item answering to specified @a strSearchTag and @a iSearchFlags. */
+        virtual UIChooserItem *searchForItem(const QString &strSearchTag, int iSearchFlags) /* override */;
 
         /** Searches for a first machine child item. */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemGroup.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemGroup.h	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemGroup.h	(revision 84625)
@@ -160,6 +160,6 @@
         virtual void removeItem(UIChooserItem *pItem) /* override */;
 
-        /** Searches for a first child item answering to specified @a strSearchTag and @a iItemSearchFlags. */
-        virtual UIChooserItem *searchForItem(const QString &strSearchTag, int iItemSearchFlags) /* override */;
+        /** Searches for a first child item answering to specified @a strSearchTag and @a iSearchFlags. */
+        virtual UIChooserItem *searchForItem(const QString &strSearchTag, int iSearchFlags) /* override */;
 
         /** Searches for a first machine child item. */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemMachine.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemMachine.h	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItemMachine.h	(revision 84625)
@@ -125,6 +125,6 @@
         virtual void removeItem(UIChooserItem *pItem) /* override */;
 
-        /** Searches for a first child item answering to specified @a strSearchTag and @a iItemSearchFlags. */
-        virtual UIChooserItem *searchForItem(const QString &strSearchTag, int iItemSearchFlags) /* override */;
+        /** Searches for a first child item answering to specified @a strSearchTag and @a iSearchFlags. */
+        virtual UIChooserItem *searchForItem(const QString &strSearchTag, int iSearchFlags) /* override */;
 
         /** Searches for a first machine child item. */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.h	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.h	(revision 84625)
@@ -198,7 +198,7 @@
     /** @name Search stuff.
       * @{ */
-        /** Performs a search starting from the m_pInvisibleRootNode. */
-        virtual void performSearch(const QString &strSearchTerm, int iItemSearchFlags) /* override */;
-        /** Cleans the search result data members and disables item's visual effects.
+        /** Performs a search using @a strSearchTerm and @a iSearchFlags specified. */
+        virtual void performSearch(const QString &strSearchTerm, int iSearchFlags) /* override */;
+        /** Resets the search result data members and disables item's visual effects.
           * Also returns a list of all nodes which may be utilized by the calling code. */
         virtual QList<UIChooserNode*> resetSearch() /* override */;
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNode.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNode.h	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNode.h	(revision 84625)
@@ -119,7 +119,7 @@
     UIChooserItem *item() const { return m_pItem.data(); }
 
-    /** Performs search wrt. @a strSearchTerm and @a iItemSearchFlags and updates @a matchedItems. For an empty
-      * @a strSearchTerm all items are added wrt. node type from @a iItemSearchFlags. */
-    virtual void searchForNodes(const QString &strSearchTerm, int iItemSearchFlags, QList<UIChooserNode*> &matchedItems) = 0;
+    /** Performs search wrt. @a strSearchTerm and @a iSearchFlags and updates @a matchedItems. For an empty
+      * @a strSearchTerm all items are added wrt. node type from @a iSearchFlags. */
+    virtual void searchForNodes(const QString &strSearchTerm, int iSearchFlags, QList<UIChooserNode*> &matchedItems) = 0;
 
     /** Performs sorting of children nodes. */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeGlobal.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeGlobal.h	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeGlobal.h	(revision 84625)
@@ -84,6 +84,6 @@
     virtual int positionOf(UIChooserNode *pNode) /* override */;
 
-    /** Updates the @a matchedItems wrt. @strSearchTerm and @a iItemSearchFlags. */
-    virtual void searchForNodes(const QString &strSearchTerm, int iItemSearchFlags, QList<UIChooserNode*> &matchedItems) /* override */;
+    /** Updates the @a matchedItems wrt. @strSearchTerm and @a iSearchFlags. */
+    virtual void searchForNodes(const QString &strSearchTerm, int iSearchFlags, QList<UIChooserNode*> &matchedItems) /* override */;
 
     /** Performs sorting of children nodes. */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeGroup.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeGroup.h	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeGroup.h	(revision 84625)
@@ -102,6 +102,6 @@
     void close() { m_fOpened = false; }
 
-    /** Recursively searches for a children wrt.  @a strSearchTerm and @a iItemSearchFlags and updates the @a matchedItems. */
-    virtual void searchForNodes(const QString &strSearchTerm, int iItemSearchFlags, QList<UIChooserNode*> &matchedItems) /* override */;
+    /** Recursively searches for a children wrt.  @a strSearchTerm and @a iSearchFlags and updates the @a matchedItems. */
+    virtual void searchForNodes(const QString &strSearchTerm, int iSearchFlags, QList<UIChooserNode*> &matchedItems) /* override */;
 
     /** Performs sorting of children nodes. */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeMachine.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeMachine.h	(revision 84624)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNodeMachine.h	(revision 84625)
@@ -100,6 +100,6 @@
     virtual int positionOf(UIChooserNode *pNode) /* override */;
 
-    /** Checks if this instance matches to search  wrt. @a strSearchTerm and @a iItemSearchFlags and updates @a matchedItems. */
-    virtual void searchForNodes(const QString &strSearchTerm, int iItemSearchFlags, QList<UIChooserNode*> &matchedItems) /* override */;
+    /** Checks if this instance matches to search  wrt. @a strSearchTerm and @a iSearchFlags and updates @a matchedItems. */
+    virtual void searchForNodes(const QString &strSearchTerm, int iSearchFlags, QList<UIChooserNode*> &matchedItems) /* override */;
 
     /** Performs sorting of children nodes. */